@@ -23,7 +23,7 @@ from cmd import Cmd
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 
 import dowml
-from dowml.dowmllib import DOWMLLib, InvalidCredentials, NoCredentialsToCreateSpace, _CredentialsProvider
+from dowml.lib import DOWMLLib, InvalidCredentials, NoCredentialsToCreateSpace, _CredentialsProvider
 
 
 class CommandNeedsJobID(Exception):
@@ -422,6 +422,17 @@ Runs the specified command in a shell."""
         # the Interactive.
         return 0
 
+    def do_status(self, _):
+        """status
+Prints current configuration for the Interactive."""
+        print(f'URL: {self.lib.url}')
+        id = f'({self.lib.space_id})' if self.lib.space_id else ''
+        print(f'Space: {self.lib.space_name} {id}')
+        print(f'Type: {self.lib.model_type}, size: {self.lib.tshirt_size}, version: {self.lib.do_version}')
+        print(f'Inputs: {self.lib.inputs}, outputs: {self.lib.outputs}')
+        t = f'{self.lib.timelimit} seconds' if self.lib.timelimit else 'unlimited'
+        print(f'Time: {t}')
+
 
 def main_loop(instance, commands, prompt_at_the_end):
     # By default, we want to run the command loop
